Concordances from corp_text and
corp_cooccurrence objects.
corp_concordance(obj, span, nodes, collocates, context) # S3 method for corp_concordance
print(x, collocates = attr(x, "collocates"),
collocate_marker = "*", as_data_table = FALSE, ...)
Returns a corp_concordance object.
A corp_text or a corp_cooccurrence object.
A character string defining the co-occurrence span.
See details section in corp_surface.
For corp_cooccurrence objects this defaults to the span
used to create the object.
A character vector of node types or character string
representing a single node type.
If supplied, only concordance lines for the specified node types will
be displayed.
For corp_cooccurrence objects this defaults to the nodes
used to create the object.
A character vector of collocate types or character string
representing a single collocate type.
If supplied, only concordance lines for the specified collocate types will
be selected (i.e. act as a filter for corp_concordance).
For corp_cooccurrence objects this defaults to the collocates
used to create the object.
For print collocates is used to determine which collocate
types to highlight; and does not act as a filter. See the "intro" vignette for
an example: vignette("intro", package = "CorporaCoCo").
Defaults to the collocates passed to the corp_concordance
function.
The number of context tokens to be displayed. Default is 3.
A corp_concordance object.
The characters used to highlight the highlighted collocates. Default is '*'.
Print the internal data.table object.
Ignored.